Welcome to MLy-Pipeline’s documentation! — mlyPipeline 0.4.2 documentation

# Welcome to MLy-Pipeline’s documentation!

MLy-Pipeline is a collection of python scripts that use MLy package tools to create low-latency, gravitational wave search of sub-second signals with generic morphologies. This documentation was created for the need of reviewing MLy-Pipeline.

Note

This project and its documentation are under active development.

# Indices and tables

- Index

- Module Index

- Search Page

## Contents

- Installation
  - Environment and installation of MLy-Pipeline
  - Updating MLy-Pipeline
- Setting up a search
  - Setting up directories
  - The runall.sh script
  - Configuration File
- Running a search
  - Ending an online search
  - With every inference
  - How manager.py manages the search part 1
  - Continuous False Alarm Rate estimation
  - Efficiency Tests
  - Trigger handling
  - How manager.py manages the search part 2
  - Monitoring the search
  - After the first ten minutes
  - After roughly an hour